@@ -54,7 +54,7 @@ def form_test_profiles(tests: List[Test], loops: int, **kwargs):
             try:
                 value = method(**kwargs)
             except BaseException as error:
-                message = f"error:{name}.{str(error).replace('\n',' ')}"
+                message = f"error:{name}.{str(error)}".replace('\n',' ')
                 print(message)
                 break
             time = __time() - start
